]> granicus.if.org Git - libnl/commitdiff
restructure module documentation order
authorThomas Graf <tgr@plip.localdomain>
Wed, 10 Dec 2008 17:12:30 +0000 (18:12 +0100)
committerThomas Graf <tgr@plip.localdomain>
Wed, 10 Dec 2008 17:12:30 +0000 (18:12 +0100)
split hiearchy into one top level module per library

13 files changed:
lib/addr.c
lib/cache_mngt.c
lib/data.c
lib/family.c [deleted file]
lib/fib_lookup/lookup.c
lib/genl/genl.c
lib/handlers.c
lib/msg.c
lib/netfilter/nfnl.c
lib/nl.c
lib/route/rtnl.c
lib/socket.c
lib/utils.c

index d5af9a54b8c3cfb098deb588a7e59b3faf7fe97f..1f000e75f855f92615c27f977e0cf1f190a56b9f 100644 (file)
@@ -10,7 +10,7 @@
  */
 
 /**
- * @ingroup utils
+ * @ingroup core
  * @defgroup addr Abstract Address
  *
  * @par 1) Transform character string to abstract address
index 4fede92cb8dab78eb1c19496d7b6d0035ec3d884..d57d8364a8a79d42c612c525efc5f61e4c8090a9 100644 (file)
@@ -10,6 +10,7 @@
  */
 
 /**
+ * @ingroup core
  * @defgroup cache_mngt Caching
  * @{
  */
index fb46a645a7c269b6938c7f7c61eb4547c935327b..03cd9fecd1f04015113abfded325ffd1223b9fa6 100644 (file)
@@ -10,7 +10,7 @@
  */
 
 /**
- * @ingroup utils
+ * @ingroup core
  * @defgroup data Abstract Data
  * @{
  */
diff --git a/lib/family.c b/lib/family.c
deleted file mode 100644 (file)
index ba1d65f..0000000
+++ /dev/null
@@ -1,62 +0,0 @@
-/*
- * lib/family.c                Netlink Family
- *
- *     This library is free software; you can redistribute it and/or
- *     modify it under the terms of the GNU Lesser General Public
- *     License as published by the Free Software Foundation version 2.1
- *     of the License.
- *
- * Copyright (c) 2003-2006 Thomas Graf <tgraf@suug.ch>
- */
-
-/**
- * @defgroup nlfam Netlink Families
- * @brief
- *
- * @{
- */
-
-#include <netlink-local.h>
-#include <netlink/netlink.h>
-#include <netlink/utils.h>
-
-/**
- * @name Netlink Family Name Translation
- * @{
- */
-
-static struct trans_tbl nlfamilies[] = {
-       __ADD(NETLINK_ROUTE,route)
-       __ADD(NETLINK_USERSOCK,usersock)
-       __ADD(NETLINK_FIREWALL,firewall)
-       __ADD(NETLINK_INET_DIAG,inetdiag)
-       __ADD(NETLINK_NFLOG,nflog)
-       __ADD(NETLINK_XFRM,xfrm)
-       __ADD(NETLINK_SELINUX,selinux)
-       __ADD(NETLINK_ISCSI,iscsi)
-       __ADD(NETLINK_AUDIT,audit)
-       __ADD(NETLINK_FIB_LOOKUP,fib_lookup)
-       __ADD(NETLINK_CONNECTOR,connector)
-       __ADD(NETLINK_NETFILTER,netfilter)
-       __ADD(NETLINK_IP6_FW,ip6_fw)
-       __ADD(NETLINK_DNRTMSG,dnrtmsg)
-       __ADD(NETLINK_KOBJECT_UEVENT,kobject_uevent)
-       __ADD(NETLINK_GENERIC,generic)
-       __ADD(NETLINK_SCSITRANSPORT,scsitransport)
-       __ADD(NETLINK_ECRYPTFS,ecryptfs)
-};
-
-char * nl_nlfamily2str(int family, char *buf, size_t size)
-{
-       return __type2str(family, buf, size, nlfamilies,
-                         ARRAY_SIZE(nlfamilies));
-}
-
-int nl_str2nlfamily(const char *name)
-{
-       return __str2type(name, nlfamilies, ARRAY_SIZE(nlfamilies));
-}
-
-/** @} */
-
-/** @} */
index bb3837a12e28901e87569e03efdbf39ff5587a47..ce9c027ebe1fc5e6b1dd9ce3fa5f1548405f04fb 100644 (file)
@@ -10,7 +10,6 @@
  */
 
 /**
- * @ingroup nlfam
  * @defgroup fib_lookup FIB Lookup
  * @brief
  * @{
index 4db17e99f8482dfd513fb6703958526324782e0f..055be919e1d35d71b0ce69f1880b2b1cfb5ec89b 100644 (file)
@@ -10,7 +10,6 @@
  */
 
 /**
- * @ingroup nlfam
  * @defgroup genl Generic Netlink
  *
  * @par Message Format
index 36695b2a2786ae0dbff35e52b49d72e20d1e2f16..f13b89ea7fdce1b04c631a7f23946f78dd9063db 100644 (file)
@@ -10,7 +10,7 @@
  */
 
 /**
- * @ingroup nl
+ * @ingroup core
  * @defgroup cb Callbacks/Customization
  *
  * @details
index d08d057e8ff7ec18cb2ef568d4ad909f7b698bda..22761a09a98c95449fe797236e579a8e4bfe8e03 100644 (file)
--- a/lib/msg.c
+++ b/lib/msg.c
@@ -10,7 +10,7 @@
  */
 
 /**
- * @ingroup nl
+ * @ingroup core
  * @defgroup msg Messages
  * Netlink Message Construction/Parsing Interface
  * 
index b687636f22c9a32af0e133d5300b13d631160ed0..ddce4b989d2fe9b8a3bf49903fa041fa6b72fa72 100644 (file)
@@ -12,7 +12,6 @@
  */
 
 /**
- * @ingroup nlfam
  * @defgroup nfnl Netfilter Netlink
  *
  * @par Message Format
index 78707ad50a9ebd22864811d62e49b69aec827ebb..eeebe1449f28ad06f6ff8f6b93af394942d6db9c 100644 (file)
--- a/lib/nl.c
+++ b/lib/nl.c
@@ -10,7 +10,7 @@
  */
 
 /**
- * @defgroup nl Core Netlink API
+ * @defgroup core Core
  *
  * @details
  * @par 1) Connecting the socket
index f87c5f56a5b26df771889a360eee940efeac1594..25336745a6e992ac95b98e4c4712c50bb430f98d 100644 (file)
@@ -10,8 +10,7 @@
  */
 
 /**
* @ingroup nlfam
* @defgroup rtnl Routing Netlink
  * @{
  */
 
index 2cebf2795996eda8cb0094ec4f5a974b0ca860c6..d1874f00835bfe53c018e203651d1a7918b9af62 100644 (file)
@@ -10,7 +10,7 @@
  */
 
 /**
- * @ingroup nl
+ * @ingroup core
  * @defgroup socket Socket
  * @{
  */
index ad254680a088282dbaa8c596fbb3b596c81f8291..263eb386591e3f58ff96e7b4e54b88a75799ef49 100644 (file)
@@ -10,6 +10,7 @@
  */
 
 /**
+ * @ingroup core
  * @defgroup utils Utilities
  * @{
  */
@@ -433,6 +434,47 @@ char * nl_msec2str(uint64_t msec, char *buf, size_t len)
 
 /** @} */
 
+/**
+ * @name Netlink Family Translations
+ * @{
+ */
+
+static struct trans_tbl nlfamilies[] = {
+       __ADD(NETLINK_ROUTE,route)
+       __ADD(NETLINK_USERSOCK,usersock)
+       __ADD(NETLINK_FIREWALL,firewall)
+       __ADD(NETLINK_INET_DIAG,inetdiag)
+       __ADD(NETLINK_NFLOG,nflog)
+       __ADD(NETLINK_XFRM,xfrm)
+       __ADD(NETLINK_SELINUX,selinux)
+       __ADD(NETLINK_ISCSI,iscsi)
+       __ADD(NETLINK_AUDIT,audit)
+       __ADD(NETLINK_FIB_LOOKUP,fib_lookup)
+       __ADD(NETLINK_CONNECTOR,connector)
+       __ADD(NETLINK_NETFILTER,netfilter)
+       __ADD(NETLINK_IP6_FW,ip6_fw)
+       __ADD(NETLINK_DNRTMSG,dnrtmsg)
+       __ADD(NETLINK_KOBJECT_UEVENT,kobject_uevent)
+       __ADD(NETLINK_GENERIC,generic)
+       __ADD(NETLINK_SCSITRANSPORT,scsitransport)
+       __ADD(NETLINK_ECRYPTFS,ecryptfs)
+};
+
+char * nl_nlfamily2str(int family, char *buf, size_t size)
+{
+       return __type2str(family, buf, size, nlfamilies,
+                         ARRAY_SIZE(nlfamilies));
+}
+
+int nl_str2nlfamily(const char *name)
+{
+       return __str2type(name, nlfamilies, ARRAY_SIZE(nlfamilies));
+}
+
+/**
+ * @}
+ */
+
 /**
  * @name Link Layer Protocol Translations
  * @{
@@ -10,8 +10,7 @@
 
 /**
- * @ingroup nlfam
- * @defgroup rtnl Routing Netlink
+ * @defgroup rtnl Routing Family
  * @{
  */